/****************************************************
AboutSQLServer.com blog
Written by Dmitri Korotkevitch

'A' = N'A'
2010-12-09
*****************************************************/
set nocount on
go

create table dbo.Data
(
	Id int not null identity(1,1),
	LargeField nvarchar(540) not null,
	Placeholder char(200) null
		constraint DEF_Data_Placeholder
		default 'The placeholder',
	 
	constraint PK_Data
	primary key clustered(ID)
)
go

declare
	@I int
	
select @I = 0

begin tran
	while @I < 50000
	begin
		insert into dbo.Data(LargeField) 
		values(REPLICATE(convert(nvarchar(36),NEWID()),15))
		
		select @I += 1
	end
commit
go

/* Enable execution plan */
set statistics io on
go

/* Table Scan */

declare
	@Param nvarchar(540)
	
select @Param = LargeField from dbo.Data where Id = 100

select * from dbo.Data where LargeField = @Param
go

/* You cannot create the index - key size > 900 bytes*/
create unique nonclustered index IDX_Data_LargeField
on dbo.Data(LargeField)
go

/* Add calculated persistent column */
alter table dbo.Data
add
	LargeFieldCheckSum as CHECKSUM(LargeField)
	PERSISTED
go

/* Don't forget to rebuild the clustered index */
alter index PK_Data on dbo.Data REBUILD
go

/* Create the index on the column */
create index IDX_Data_LargeFieldCheckSum 
on dbo.Data(LargeFieldCheckSum)
go

/* Now let's modify select a little bit */
declare
	@Param nvarchar(540)
	
select @Param = LargeField from dbo.Data where Id = 100

select * 
from dbo.Data 
where LargeField = @Param and LargeFieldCheckSum  = CHECKSUM(@Param)
go

